#!/bin/bash

LOG_FILE=/var/log/mysql_install.log
HOST_DATA_DIR=/var/lib/mysql
CONTAINER_NAME=mysql
APP_VERSION=5.5
APP_IMAGE=$CONTAINER_NAME:$APP_VERSION

preCheck() {
    
    if ! command -v tee > /dev/null; then
        echo "`date` tee command not found. Please install tee." >> $LOG_FILE
        exit 1
    fi

    if ! command -v docker-compose > /dev/null; then
        echo "`date` docker-compose command not found. Please install docker-compose." | tee -a $LOG_FILE
        exit 1
    fi
    
    if [ -z "$1" ]; then
        echo "`date` Parameter port is missing or empty." | tee -a $LOG_FILE
        exit 1
    fi
    
    if [ -z "$2" ]; then
        echo "`date` Parameter root passord is missing or empty." | tee -a $LOG_FILE
        exit 1
    fi
    
    PORT=$1
    
    if netstat -tuln | grep ":$PORT " > /dev/null
    then
        echo "`date` Port $PORT is in use" | tee -a $LOG_FILE
        return 1
    else
        echo "`date` Port $PORT is not in use" | tee -a $LOG_FILE
        return 0
    fi
}

install() {
    
    PORT=$1
    ROOT_PASSWORD=$2
    echo "`date` start install $CONTAINER_NAME on port $PORT with root password $ROOT_PASSWORD" | tee -a $LOG_FILE
    # Create docker-compose.yml
    echo "version: '3.1'" > docker-compose.yml
    echo "services:" >> docker-compose.yml
    echo "  $CONTAINER_NAME:" >> docker-compose.yml
    echo "    image: $APP_IMAGE" >> docker-compose.yml
    echo "    container_name: $CONTAINER_NAME" >> docker-compose.yml
    echo "    restart: always" >> docker-compose.yml
    echo "    ports:" >> docker-compose.yml
    echo "      - $PORT:3306" >> docker-compose.yml
    echo "    network_mode: host" >> docker-compose.yml
    echo "    environment:" >> docker-compose.yml
    echo "      MYSQL_ROOT_PASSWORD: $ROOT_PASSWORD" >> docker-compose.yml
    echo "      MYSQL_DATABASE: wordpress" >> docker-compose.yml
    echo "      MYSQL_USER: wordpress" >> docker-compose.yml
    echo "      MYSQL_PASSWORD: wordpress" >> docker-compose.yml
    echo "    volumes:" >> docker-compose.yml
    echo "      - $HOST_DATA_DIR:/var/lib/mysql" >> docker-compose.yml
    
    # Start MySQL
    docker-compose up -d
    upResult=$?
    if [ $upResult -ne 0 ]; then
        echo "`date` install $CONTAINER_NAME failed with exit code $upResult" | tee -a $LOG_FILE
        return 1
    fi
    echo "`date` wait 10 seconds for $CONTAINER_NAME to start" | tee -a $LOG_FILE
    sleep 10
    
    return 0
}

postCheck() {
    echo "`date` start post check for $CONTAINER_NAME installation" | tee -a $LOG_FILE
    # Check MySQL status
    if ! docker-compose ps | grep $CONTAINER_NAME | grep Up > /dev/null; then
        echo "`date` MySQL is not running." | tee -a $LOG_FILE
        return 1
    fi
    return 0
}

# step 1: pre-Check
preCheck $1 $2
preCheckResult=$?
echo "`date` pre check result is $preCheckResult" | tee -a $LOG_FILE
if [ $preCheckResult -eq 0 ]
then
    echo "`date` Pre-check successful." | tee -a $LOG_FILE
    # Step 2: Install MySQL
    install $1 $2
    installResult=$?
    if [ $installResult -eq 0 ]
    then
        echo "`date` Install MySQL successful." | tee -a $LOG_FILE
        # Step 3: Post-check
        postCheck
        postCheckResult=$?
        if [ $postCheckResult -eq 0 ]
        then
            echo "`date` Post-check successful." | tee -a $LOG_FILE
            echo "`date` MySQL installation process completed." | tee -a $LOG_FILE
            exit 0
        else
            echo "`date` Post-check failed." | tee -a $LOG_FILE
            exit 3
        fi
    else
        echo "`date` Install MySQL failed." | tee -a $LOG_FILE
        exit 2
    fi
else
    echo "`date` Pre-check failed." | tee -a $LOG_FILE
    exit 1
fi