#!/bin/bash

LOG_FILE=/var/log/mysql_shutdown.log
CONTAINER_NAME=mysql

if ! command -v tee > /dev/null; then
    echo "`date` tee command not found. Please install tee." >> $LOG_FILE
    exit 12
fi

if ! command -v docker-compose > /dev/null; then
    echo "`date` docker-compose command not found. Please install docker-compose." | tee -a $LOG_FILE
    exit 12
fi

# Check MySQL status
if ! docker-compose ps | grep $CONTAINER_NAME | grep Up > /dev/null; then
    echo "`date` MySQL is closed." | tee -a $LOG_FILE
    exit 0
fi

# shutdown Mysql
docker-compose down
echo "`date` wait 10 seconds for $CONTAINER_NAME to shutdown" | tee -a $LOG_FILE
sleep 10

# Check MySQL status
if docker-compose ps | grep $CONTAINER_NAME | grep Up > /dev/null; then
    echo "`date` MySQL is running." | tee -a $LOG_FILE
    exit 12
fi
exit 0