#!/bin/bash

LOG_FILE=/var/log/mysql_uninstall.log
HOST_DATA_DIR=/var/lib/mysql
CONTAINER_NAME=mysql
APP_VERSION=5.5
APP_IMAGE=$CONTAINER_NAME:$APP_VERSION

preCheck() {
    
    if ! command -v tee > /dev/null; then
        echo "`date` tee command not found. Please install tee." >> $LOG_FILE
        exit 1
    fi
    
    if ! command -v docker-compose > /dev/null; then
        echo "`date` docker-compose command not found. Please install docker-compose." | tee -a $LOG_FILE
        exit 1
    fi
    
    if ! command -v docker > /dev/null; then
        echo "`date` docker command not found. Please install docker." | tee -a $LOG_FILE
        exit 1
    fi
    return 0
}

uninstall() {
    # Stop MySQL
    docker-compose down
    echo "`date` wait 10 seconds for $CONTAINER_NAME to stop" | tee -a $LOG_FILE
    sleep 10
    
    # Clear docker images
    docker rmi $APP_IMAGE
    
    # Clear data
    rm -rf $HOST_DATA_DIR
    return 0
}

postCheck() {
    echo "`date` start post check for $CONTAINER_NAME uninstallation" | tee -a $LOG_FILE
    
    # Check MySQL status
    if docker-compose ps | grep $CONTAINER_NAME | grep Up > /dev/null; then
        echo "`date` MySQL is running." | tee -a $LOG_FILE
        return 1
    fi

    # Clear docker images
    if docker images | grep $CONTAINER_NAME | grep $APP_VERSION > /dev/null; then
        echo "`date` MySQL image is not removed." | tee -a $LOG_FILE
        return 1
    fi


    if [ -d "$HOST_DATA_DIR" ]; then
        echo "`date` MySQL data is not removed." | tee -a $LOG_FILE
        return 1
    fi
    
    return 0
}

# step 1: pre-Check
preCheck
preCheckResult=$?
echo "`date` pre check result is $preCheckResult" | tee -a $LOG_FILE
if [ $preCheckResult -eq 0 ]
then
    echo "`date` Pre-check successful." | tee -a $LOG_FILE
    # Step 2: Uninstall MySQL
    uninstall
    uninstallResult=$?
    if [ $uninstallResult -eq 0 ]
    then
        echo "`date` Uninstall MySQL successful." | tee -a $LOG_FILE
        # Step 3: Post-check
        postCheck
        postCheckResult=$?
        if [ $postCheckResult -eq 0 ]
        then
            echo "`date` Post-check successful." | tee -a $LOG_FILE
            echo "`date` MySQL uninstallation process completed." | tee -a $LOG_FILE
            exit 0
        else
            echo "`date` Post-check failed." | tee -a $LOG_FILE
            exit 9
        fi
    else
        echo "`date` Uninstall MySQL failed." | tee -a $LOG_FILE
        exit 8
    fi
else
    echo "`date` Pre-check failed." | tee -a $LOG_FILE
    exit 7
fi